==> aegis_3.8.orig.tar.gz: aegis-3.8.orig/aefind/tree/arithmetic.h <==
/*
 *	aegis - project change supervisor
 *	Copyright (C) 1997 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for aefind/tree/arithmetic.c
 */

#ifndef AEFIND_TREE_ARITHMETIC_H
#define AEFIND_TREE_ARITHMETIC_H

#include <main.h>

struct tree_ty *tree_divide_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_join_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_subtract_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_mod_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_mul_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_neg_new _((struct tree_ty *));
struct tree_ty *tree_plus_new _((struct tree_ty *, struct tree_ty *));
struct tree_ty *tree_pos_new _((struct tree_ty *));

#endif /* AEFIND_TREE_ARITHMETIC_H */

==> aegis_4.21.orig.tar.gz: aegis-4.21/aefind/tree/arithmetic.h <==
/*
 *	aegis - project change supervisor
 *	Copyright (C) 1997, 2002 Peter Miller;
 *	All rights reserved.
 *
 *	This program is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This program is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this program; if not, write to the Free Software
 *	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 * MANIFEST: interface definition for aefind/tree/arithmetic.c
 */

#ifndef AEFIND_TREE_ARITHMETIC_H
#define AEFIND_TREE_ARITHMETIC_H

#include <main.h>

struct tree_ty *tree_divide_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_join_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_subtract_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_mod_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_mul_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_neg_new(struct tree_ty *);
struct tree_ty *tree_plus_new(struct tree_ty *, struct tree_ty *);
struct tree_ty *tree_pos_new(struct tree_ty *);

#endif /* AEFIND_TREE_ARITHMETIC_H */
